# coding: UTF-8
import serial
import cv2
import numpy as np

def s2i(data): #Short(2バイト)をIntに変換
    num = data[1]*256+data[0]
    if num >= 0x8000:
        num -= 0x10000
    return(num)

def receive_data(ser):
    try:
        r_data = [ord(ser.read())]
        for i in range(r_data[0]-1):
            r_data.append(ord(ser.read()))
    except:
        print(u"通信受信失敗")

    return(r_data)

def get_psd_s(ser): #PSDセンサー短距離用(AD5)
    com_line = [0x0A,0x00,0x20,0x00,0x00,0x00,0x2C,0x00,0x02,0x58]
    ser.write(com_line)
    r_data = receive_data(ser)
    vout = s2i(r_data[2:4])
    dist = 16067*(vout**-1.202)
    return(dist)

def main():
    #シリアル通信オープン
    com_num = 3 #COMポート番号
    try:
        ser = serial.Serial(com_num-1, 115200,parity=serial.PARITY_EVEN,timeout=1)
        print(u"シリアルポートをオープンしました")
    except:
        print(u"シリアルポートがオープンできません")
        exit()

    while True:
        img = np.empty((200,600,3),np.uint8)
        img.fill(255)

        cv2.line(img,(0,100),(600,100),(0,0,0),1)
        cv2.line(img,(250,80),(250,120),(0,0,0),1)
        cv2.line(img,(500,80),(500,120),(0,0,0),1)
        cv2.putText(img, "50cm", (230,70), cv2.FONT_HERSHEY_SIMPLEX, 0.5, (0,0,0), 1)
        cv2.putText(img, "100cm", (480,70), cv2.FONT_HERSHEY_SIMPLEX, 0.5, (0,0,0), 1)

        dist = int(get_psd_s(ser))
        cv2.putText(img, "Dist = "+str(dist)+"cm", (10,20), cv2.FONT_HERSHEY_SIMPLEX, 0.5, (255,0,0), 1)
        cv2.line(img,(0,100),(dist*5,100),(255,0,0),8)

        cv2.imshow("PSD test",img)

        #何か押されたら終了
        if cv2.waitKey(10) > 0:
            cv2.destroyAllWindows()
            #シリアル通信クローズ
            ser.close()
            print(u"シリアルポートを切断しました")
            break

#メイン関数実行
main()
